@@ -1,5 +1,25 @@
+/*
+ * Copyright (c) 2020-2021 illiliti <illiliti@protonmail.com>
+ * SPDX-License-Identifier: ISC
+ * 
+ * Permission to use, copy, modify, and/or distribute this software for any
+ * purpose with or without fee is hereby granted, provided that the above
+ * copyright notice and this permission notice appear in all copies.
+ * 
+ * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
+ * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
+ * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
+ * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
+ * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
+ * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
+ * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
+ */
+
 #include <stdarg.h>
 #include <sys/types.h>
+
+// we must keep this include here to fix some legacy programs
+// https://freenode.logbot.info/kisslinux/20200722#c4467755
 #include <sys/sysmacros.h>
 
 #ifndef _LIBUDEV_H_
@@ -109,7 +129,7 @@ struct udev_hwdb *udev_hwdb_unref(struct udev_hwdb *hwdb);
 struct udev_list_entry *udev_hwdb_get_properties_list_entry(struct udev_hwdb *hwdb, const char *modalias, unsigned int flags);
 
 // this is "libudev-zero" extension. do not use if portability is concern
-struct udev_device *udev_device_new_from_file(struct udev *udev, const char *path);
+struct udev_device *udev_device_new_from_uevent(struct udev *udev, char *buf, size_t len);
 
 #ifdef __cplusplus
 }
